@@ -27,13 +27,16 @@ async def channel_fetcher(v: str, c):
 
 
 _LINE_PATTERN = re.compile(r"([a-z0-9_.]+)\s*:\s*([a-zA-Z0-9_]+)\s*=\s*(.+)")
+NONE_TYPE = lambda _, _1: None
 DEFAULT_TYPES = {
     "str": (lambda v, _: str(v), False),
     "Base64": (lambda v, _: base64.b64decode(v).decode(), False),
     "Guild": (guild_fetcher, True),
     "Channel": (channel_fetcher, True),
     "int": (lambda v, _: int(v), False),
-    "JSON": (lambda v, _: json.loads(v), False)
+    "JSON": (lambda v, _: json.loads(v), False),
+    "Regex": (lambda v, _: re.compile(v), False),
+    "None": NONE_TYPE
 }
 
 
@@ -72,11 +75,12 @@ CustomConfigTypes = TypeVar("CustomConfigTypes", bound=dict[str, tuple[Callable[
 
 
 class SFC(AbstractConfigSection):
-    def __init__(self, path: str, application_data: Any = None, custom_types: CustomConfigTypes = None):
+    def __init__(self, path: str, application_data: Any = None, custom_types: CustomConfigTypes = None, ignore_unknown_types: bool = False):
         self.file_path: str = path
         self.application_data: Any = application_data
         self.data: Dict[str, Any] = {}
         self.types: CustomConfigTypes = {**DEFAULT_TYPES, **(custom_types or {})}
+        self.ignore_unknown_types: bool = ignore_unknown_types
 
     async def reload(self, post_ready: bool = True):
         self.data = {}
@@ -98,11 +102,14 @@ class SFC(AbstractConfigSection):
             name, type_, value = match.groups()
 
             if type_ not in self.types.keys():
+                if self.ignore_unknown_types:
+                    continue
+
                 raise TypeError(f"invalid config type: {type_}")
 
-            type_constructor, is_post_login = self.types[type_]
+            type_constructor, is_post_ready = self.types[type_]
 
-            if not post_ready and is_post_login:
+            if not post_ready and is_post_ready:
                 continue
 
             value = type_constructor(value, self.application_data)
